function [parent, NVP] = parseChartInputs(inputArgs, ChartName, varargin)
%PARSECHARTINPUTS Parses inputArgs and returns parent and Name-Value pairs 
%   INPUTARGS - Input arguments to the chart in the form of a cell array. 
%   CHARTNAME - Full package name of the Chart to be parsed. 
%   varargin - optional parser configurations in the form of Name Value
%   pairs. 

% varargin can only be Name Value pairs.
cp = matlab.graphics.chart.ChartInputParser('ChartClassName', ChartName);
args = varargin;

matlab.graphics.chart.internal.ctorHelper(cp, args);

[parent, NVP] = cp.parseInputs(inputArgs{:});

end

